@@ -274,6 +274,15 @@ int main(int argc, char* argv[])
         }
 
         if(!S_ISDIR(stat_.st_mode)) {
+            /*
+            pid_t parent_pgid = getpgid(getppid());
+            if(parent_pgid < 0) {
+                perror("getpgid");
+                exit(1);
+            }
+            (void)setpgid(0, parent_pgid);
+            */
+
             mcurses_init(code);
             saphire_set_signal_optc();
             saphire_init(kATOptC, FALSE, runtime_script, FALSE);
@@ -317,6 +326,15 @@ int main(int argc, char* argv[])
 
     /// オプションで指定されているならシェルで実行する ///
     if(send_cmd[0] == 'c') {
+        /*
+        pid_t parent_pgid = getpgid(getppid());
+        if(parent_pgid < 0) {
+            perror("getpgid");
+            exit(1);
+        }
+        (void)setpgid(0, parent_pgid);
+        */
+
         mcurses_init(code);
         saphire_set_signal_optc();
         saphire_init(kATOptC, FALSE, runtime_script, FALSE);
