@@ -464,7 +464,7 @@ void sigchld_block(int block);
 ////////////////////////////////////////////////////////////
 /// from saphire_commands.c
 ////////////////////////////////////////////////////////////
-int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, vector_obj* cprogs, char* title, BOOL input, BOOL* return_, char* sname, int line);
+int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, char* title, BOOL input, BOOL* return_, char* sname, int line);
 BOOL vcat_expand_env(string_obj* pipeout, char* env, vector_obj* numbers,char* sname, int line);
 
 ////////////////////////////////////////////////////////////
@@ -498,7 +498,7 @@ extern vector_obj* gStackTraceFName;
 extern vector_obj* gStackTraceLineNum;
     // åե졼εϿ
 
-int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL finaly_exec, BOOL in_loop, BOOL* return_, vector_obj* blocks, BOOL try_);
+int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_);
     // saphire_compile2ǥѥ뤷ѥ̤¹Ԥ롣
     // verboseϼ¹Ԥ˼¹Ԥ륳ޥ̾ɽ뤫ɤ
 
