@@ -657,6 +657,7 @@ void sig_int_optc()
 {
     sigchld_block(1);
     gKitutukiSigInt = TRUE; 
+fprintf(stderr, "SIGINT!!\n");
     sigchld_block(0);
 }
 
@@ -857,6 +858,16 @@ void saphire_set_signal()
         exit(1);
     }
 
+/*
+    memset(&sa, 0, sizeof(sa));
+    sa.sa_handler = SIG_DFL;
+    sa.sa_flags = SA_RESTART;
+    if(sigaction(SIGSTOP, &sa, NULL) < 0) {
+        perror("sigaction11");
+        exit(1);
+    }
+*/
+
     if(saphire_set_signal_other) saphire_set_signal_other();
 }
 
@@ -942,6 +953,16 @@ void saphire_set_signal_optc()
         exit(1);
     }
 
+/*
+    memset(&sa, 0, sizeof(sa));
+    sa.sa_handler = SIG_DFL;
+    sa.sa_flags = SA_RESTART;
+    if(sigaction(SIGSTOP, &sa, NULL) < 0) {
+        perror("sigaction11");
+        exit(1);
+    }
+*/
+
     if(saphire_set_signal_other) saphire_set_signal_other();
 }
 
@@ -2868,7 +2889,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.4.1", 1);
+    setenv("SAPHIRE_VERSION", "2.0.2", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
