@@ -21,7 +21,7 @@ typedef struct
 //////////////////////////////////////////////////////////////////////
 
 // 初期化
-#ifdef MDEBUG
+#if defined(MDEBUG)
 
 string_obj* string_new_debug(char* str, const char* fname, int line, const char* func_name);
 #define STRING_NEW(str) string_new_debug(str, __FILE__, __LINE__, __FUNCTION__)
